@@ -207,22 +207,42 @@ class Browser(UserAgent):
 
 		# validate incoming url
 		scheme = ""
+## 		try:
+## 			url.get_full_url
+## 		except AttributeError:
+## 			# string URL -- convert to absolute URL if required
+## 			scheme, netloc, action = urlparse.urlparse(url)[:3]
+## 			if (scheme == ""): # relative URL
+## 				if os.path.exists(url):
+## 					scheme = "file"
+## 					netloc = ""
+## 					url = "file://"+url
+## 				elif (self.response is None):
+## 					raise BrowserStateError("Incomplete URL")
+## 				else:
+## 					url = urlparse.urljoin(self.response.geturl(), url)
+## 		else:
+## 			scheme, netloc, action = urlparse.urlparse(url.get_full_url())[:3]
 		try:
-			url.get_full_url
-		except AttributeError:
-			# string URL -- convert to absolute URL if required
-			scheme, netloc, action = urlparse.urlparse(url)[:3]
-			if (scheme == ""): # relative URL
-				if os.path.exists(url):
-					scheme = "file"
-					netloc = ""
-					url = "file://"+url
-				elif (self.response is None):
-					raise BrowserStateError("Incomplete URL")
-				else:
-					url = urlparse.urljoin(self.response.geturl(), url)
-		else:
 			scheme, netloc, action = urlparse.urlparse(url.get_full_url())[:3]
+		except:
+			scheme, netloc, action = urlparse.urlparse(url)[:3]
+
+		# relative URL	
+		if (scheme == ""): 
+			if os.path.exists(url):
+				scheme = "file"
+				netloc = ""
+				url = "file://"+url
+			elif (self.response is None):
+				raise BrowserStateError("Incomplete URL")
+			else:
+				url = urlparse.urljoin(self.response.geturl(), url)
+
+		# local files	
+		if (self.last_scheme == "file"):
+			url = self.pwd + urlparse.urlparse(url.get_full_url())[2]
+
 		#last action	
 		if (action.find("cgi-bin") != -1):
 			self.last_action = "cgi-bin"
@@ -230,9 +250,6 @@ class Browser(UserAgent):
 			self.last_action = "cgibin"
 		else:
 			self.last_action = ""
-		# local files	
-		if (self.last_scheme == "file"):
-			url = self.pwd + urlparse.urlparse(url.get_full_url())[2]
  
 		# self.request assigned even if OpenerDirector.open fails
 		self.request = self.get_request(url, data)
@@ -365,7 +382,7 @@ class Browser(UserAgent):
 		elif kwds:
 			raise ValueError("Pass either a link or keyword arguments, not both.")
 		# rh::fix failure of urls "some.html" and "/some.html"
-		if ((link.absolute_url.find("cgi-bin") == -1) or
+		if ((link.absolute_url.find("cgi-bin") == -1) and
 			(link.absolute_url.find("cgibin") == -1)):
 			last_host = self.last_host+"/"+self.last_action
 		else:
